@@ -2,10 +2,7 @@ package Pod::Readme::Plugin::changes;
 
 use Moo::Role;
 
-{
-    use version 0.77;
-    $Pod::Readme::Plugin::changes::VERSION = version->declare('v1.1.1');
-}
+our $VERSION = 'v1.2.0';
 
 use CPAN::Changes 0.30;
 use Path::Tiny;
@@ -128,7 +125,7 @@ sub cmd_changes {
 
     my %opts;
     if ($self->zilla) {
-      $opts{next_token} = qr/{{\$NEXT}}/;
+      $opts{next_token} = qr/\{\{\$NEXT}}/;
     }
 
     my $changes = CPAN::Changes->load($file, %opts);
